=======================================
``psyclone.domain.nemo.nemo_constants``
=======================================

.. automodule:: psyclone.domain.nemo.nemo_constants

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.nemo_constants


Classes
=======

- :py:class:`NemoConstants`:
  This class stores all Nemo constants.


.. autoclass:: NemoConstants
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NemoConstants
      :parts: 1
